@@ -16,7 +16,7 @@ use strict;
 use warnings;
 use vars qw( %Known %PackSize %Modifier %Pointer $VERSION @ISA );
 
-$VERSION = '0.64_02';
+$VERSION = '0.68';
 
 use Carp;
 BEGIN{
@@ -114,7 +114,8 @@ sub typedef {
     $name =~ m/^(.+?)\s*(\*)$/;
     $name = $1;
     $name .= $2 if defined $2;
-    my $packing = packing($type, $name);
+    #FIXME BUG, unsigned __int64 * doesn't pase in typedef, it does in parse_prototype
+    my $packing = packing($type, $name); #FIXME BUG
     if(! defined $packing){
         warn "Win32::API::Type::typedef: WARNING unknown type '$_[1]'";
         return undef;
@@ -272,13 +273,13 @@ sub Pack {
         return;
     }
     elsif(IVSIZE() == 4 && ($pack_type eq 'q' || $pack_type eq 'Q')){
-        if($_[0]->{'UseMI64'}){ #un/signed meaningless
+        if($_[0]->UseMI64() || ref($_[2])){ #un/signed meaningless
             $_[2] = Math::Int64::int64_to_native($_[2]);
         }
         else{
             if(length($_[2]) < 8){
                 warn("Win32::API::Call value for 64 bit integer is under 8 bytes long");
-                $_[2] = pack('a[8]', $_[2]);
+                $_[2] = pack('a8', $_[2]);
             }
         }
         return;
@@ -300,13 +301,13 @@ sub Unpack {
     elsif(IVSIZE() == 4){
         #todo debugging output
         if($pack_type eq 'q'){
-            if($_[0]->{'UseMI64'}){
+            if($_[0]->UseMI64() || ref($_[2])){
             $_[2] = Math::Int64::native_to_int64($_[2]);
             DEBUG "(PM)Type::Unpack: returning signed Math::Int64 '".$_[2]."'\n";
             }
             return;
         }elsif($pack_type eq 'Q'){
-            if($_[0]->{'UseMI64'}){
+            if($_[0]->UseMI64() || ref($_[2])){
             $_[2] = Math::Int64::native_to_uint64($_[2]);
             DEBUG "(PM)Type::Unpack: returning unsigned Math::Int64 '".$_[2]."'\n";
             }
@@ -487,6 +488,7 @@ LONG64                  q
 LONGLONG                q
 LPARAM                  _P
 LRESULT                 _P
+NTSTATUS                l
 REGSAM                  L
 SC_HANDLE               _P
 SC_LOCK                 _P
